@@ -298,7 +298,9 @@ $plan = $parent ? &get_plan($parent->{'plan'}) :
          'owner', "Migrated Plesk server $dom",
          'email', $email ? $email : $parent ? $parent->{'email'} : undef,
 	 'dns_ip', $ipinfo->{'virt'} ? undef :
-		   &get_dns_ip($parent ? $parent->{'id'} : undef),
+		   &get_dns_ip($parent ? $parent->{'resel'} : undef, 4),
+	 'dns_ip6', $ipinfo->{'virt6'} ? undef :
+		    &get_dns_ip($parent ? $parent->{'resel'} : undef, 6),
 	 $parent ? ( 'pass', $parent->{'pass'} )
 		 : ( 'pass', $pass ),
 	 'source', 'migrate.cgi',
