@@ -66,8 +66,7 @@ if (!defined($first_print)) {
 	}
 
 # For the GPL version, force some features off.
-$virtualmin_pro = $module_info{'version'} =~ /pro/i ||
-		  -d "$module_root_directory/pro" ? 1 : 0;
+$virtualmin_pro = -d "$module_root_directory/pro" ? 1 : 0;
 if (!$virtualmin_pro) {
 	$config{'status'} = 0;
 	}
@@ -217,9 +216,10 @@ $plans_dir = "$module_config_directory/plans";
 $extra_users_dir = "$module_config_directory/users";
 
 $extra_admins_dir = "$module_config_directory/admins";
-@all_possible_php_versions = ( 5, 5.2, 5.3, 5.4, 5.5, 5.6,
-                              "7.0", 7.1, 7.2, 7.3, 7.4,
-                              "8.0", 8.1, 8.2, 8.3, 8.4 );
+@all_possible_php_versions = (
+	5, 5.2, 5.3, 5.4, 5.5, 5.6,
+	"7.0", 7.1, 7.2, 7.3, 7.4,
+	"8.0", 8.1, 8.2, 8.3, 8.4, 8.5, 8.6, 8.7, 8.8, 8.9 );
 @all_possible_short_php_versions =
 	&unique(map { int($_) } @all_possible_php_versions);
 $max_php_fcgid_children = $config{'max_php_fcgi_children'} || int(&get_php_max_childred_allowed() * 5) || 5;
@@ -368,7 +368,7 @@ $ham_alias_dir = "$trap_base_dir/ham";
 $user_quota_warnings_file = "$module_config_directory/quotas-warnings";
 $user_quota_msg_file = "$module_config_directory/quotas-template";
 
-@automatic_dns_records = ( "@", "www", "ftp", "localhost", "m");
+@automatic_dns_records = ( "@", "www", "ftp");
 
 $links_cache_dir = &cache_file_path("links-cache");
 
